@@ -10,6 +10,9 @@
 {-# LANGUAGE ScopedTypeVariables #-}
 {-# LANGUAGE AllowAmbiguousTypes #-}
 {-# LANGUAGE Trustworthy #-}
+#if __GLASGOW_HASKELL__ >= 805
+{-# LANGUAGE NoStarIsType #-}
+#endif
 -- | Utilities for working with 'KnownNat' constraints.
 --
 -- This module is only available on GHC 8.0 or later.
@@ -39,6 +42,7 @@ module Data.Constraint.Nat
   , timesDiv
   , eqLe, leEq, leId, leTrans
   , leZero, zeroLe
+  , plusMinusInverse1, plusMinusInverse2, plusMinusInverse3
   ) where
 
 import Data.Constraint
@@ -152,6 +156,15 @@ leZero = Sub axiom
 zeroLe :: forall a. Dict (0 <= a)
 zeroLe = Dict
 
+plusMinusInverse1 :: forall n m. Dict (((m + n) - n) ~ m)
+plusMinusInverse1 = axiom
+
+plusMinusInverse2 :: forall n m. (m <= n) :- (((m + n) - m) ~ n)
+plusMinusInverse2 = Sub axiom
+
+plusMinusInverse3 :: forall n m. (n <= m) :- (((m - n) + n) ~ m)
+plusMinusInverse3 = Sub axiom
+
 plusMonotone1 :: forall a b c. (a <= b) :- (a + c <= b + c)
 plusMonotone1 = Sub axiom
 
